Not

Struct Not 

pub struct Not<'a> {
    pub constraint: Constraint<'a>,
}
A constrait that inverts the outcome of another constraint.

This is useful to define negation of existing constraints. For example, a constraint that succeeds when an account is not owned by a specific program.

Fields

constraint: Constraint<'a>