Extension

Struct Extension 

pub struct Extension { /* private fields */ }
The Extension struct is used to store the “header” information for an extension.

This information is added at the start of each extension data and it is used to determine the type of extension and the length of the extension data.

Implementations

Source

impl Extension

pub const LEN: usize

pub fn new( extension_type: ExtensionType, length: u32, boundary: u32, ) -> Extension

pub fn try_extension_type(&self) -> Result<ExtensionType, Error>

Try to get the extension type.

The extension type is stored as a u32 on the acccount data. This method tries to perform the conversion to an ExtensionType and returns an error if the conversion fails – e.g., the u32 value is not a valid extension type. This can happen when a new extension type is added and an older version of the library is used.

pub fn extension_type(&self) -> ExtensionType

Returns the extension type.

This method is similar to try_extension_type, but panics if the u32 value on the account data cannot be converted to an ExtensionType.

pub fn set_extension_type(&mut self, extension_type: ExtensionType)

pub fn length(&self) -> u32

pub fn set_length(&mut self, length: u32)

pub fn boundary(&self) -> u32

Returns the boundary of the extension.

The boundary is the number of bytes from the start of the extension to the start of the next extension. This is used specify any padding that may be required to maintain byte alignment.

Note that the boundary might be larger than the length of the extension data.

pub fn set_boundary(&mut self, boundary: u32)

pub fn get<'a, T>(data: &'a [u8]) -> Option<T>
where T: ExtensionData<'a>,

Returns the extension data of a given type.

This function expects a slice of bytes of extension data only and it will return the first extension of the given type; if the extension type is not found, None is returned.

pub fn get_mut<'a, T>(data: &'a mut [u8]) -> Option<T>
where T: ExtensionDataMut<'a>,

Returns a mutable reference to the extension data of a given type.

This function expects a slice of bytes of extension data only and it will return the first extension of the given type; if the extension type is not found, None is returned.