Grouping

Struct Grouping 

pub struct Grouping<'a> {
    pub size: &'a u64,
    pub max_size: &'a PodOption<NullableU64>,
    pub delegate: &'a PodOption<NullablePubkey>,
}
Extension to define a group of assets.

Assets that are intented to be use as group “markers” must have this extension attached to them.

The size of the group is updated every time an asset is added or removed from the group. Additionally, the size is decreased when an asset is burned.

Fields

size: &'a u64

The number of assets in the group.

max_size: &'a PodOption<NullableU64>

The maximum number of assets that can be in the group.

When the group is unlimited, this value is 0.

delegate: &'a PodOption<NullablePubkey>

An optional delegate authorised to add assets to this group