MetadataMut

Struct MetadataMut 

pub struct MetadataMut<'a> {
    pub symbol: U8PrefixStrMut<'a>,
    pub description: U8PrefixStrMut<'a>,
    pub uri: U8PrefixStrMut<'a>,
    pub image_uri: U8PrefixStrMut<'a>,
}
Mutable reference to Metadata extension.

This type is used to modify the Metadata extension. Note that the symbol, description and uri fields are mutable references to the original bytes, but cannot increase in size.

Fields

symbol: U8PrefixStrMut<'a>

Symbol for the asset.

description: U8PrefixStrMut<'a>

Description of the asset.

uri: U8PrefixStrMut<'a>

“Pointer” URI for external metadata.

image_uri: U8PrefixStrMut<'a>

“Pointer” URI for external image.