pub struct Proxy<'a> {
pub program: &'a Pubkey,
pub seeds: &'a [u8; 32],
pub bump: &'a u8,
pub authority: &'a PodOption<NullablePubkey>,
}Expand description
Extension to define the proxy data of a proxied asset.
Assets with a Proxied standard are controlled by the proxy
program specified in this extension.
This extension can only be used in Proxied asset accounts.
Fields
program: &'a PubkeyThe proxy program.
seeds: &'a [u8; 32]The seeds for the PDA derivation.
bump: &'a u8The bump for the PDA derivation.
Authority of the proxy extension.