pub struct CreateCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for Create via CPI.
Accounts:
[writable, signer]asset[signer]authority[]owner[writable, optional]group[signer, optional]group_authority[writable, signer, optional]payer[optional]system_program
Implementations
Sourceimpl<'a, 'b> CreateCpiBuilder<'a, 'b>
impl<'a, 'b> CreateCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
Sourcepub fn asset(&mut self, asset: &'b AccountInfo<'a>) -> &mut Self
pub fn asset(&mut self, asset: &'b AccountInfo<'a>) -> &mut Self
Asset account
The authority of the asset
Sourcepub fn owner(&mut self, owner: &'b AccountInfo<'a>) -> &mut Self
pub fn owner(&mut self, owner: &'b AccountInfo<'a>) -> &mut Self
The owner of the asset
Sourcepub fn group(&mut self, group: Option<&'b AccountInfo<'a>>) -> &mut Self
pub fn group(&mut self, group: Option<&'b AccountInfo<'a>>) -> &mut Self
[optional account]
Asset account of the group
[optional account]
The delegate authority for minting assets into a group
Sourcepub fn payer(&mut self, payer: Option<&'b AccountInfo<'a>>) -> &mut Self
pub fn payer(&mut self, payer: Option<&'b AccountInfo<'a>>) -> &mut Self
[optional account]
The account paying for the storage fees
Sourcepub fn system_program(
&mut self,
system_program: Option<&'b AccountInfo<'a>>,
) -> &mut Self
pub fn system_program( &mut self, system_program: Option<&'b AccountInfo<'a>>, ) -> &mut Self
[optional account]
The system program
pub fn name(&mut self, name: String) -> &mut Self
Sourcepub fn standard(&mut self, standard: Standard) -> &mut Self
pub fn standard(&mut self, standard: Standard) -> &mut Self
[optional argument, defaults to 'Standard::NonFungible']
Sourcepub fn extensions(&mut self, extensions: Vec<ExtensionInput>) -> &mut Self
pub fn extensions(&mut self, extensions: Vec<ExtensionInput>) -> &mut Self
[optional argument]
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult