pub struct CreateInstructionArgs {
pub name: String,
pub standard: Standard,
pub mutable: bool,
pub extensions: Option<Vec<ExtensionInput>>,
}Fields
name: Stringstandard: Standardmutable: boolextensions: Option<Vec<ExtensionInput>>Trait Implementations
Sourceimpl BorshDeserialize for CreateInstructionArgs
impl BorshDeserialize for CreateInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateInstructionArgswhere
String: BorshSerialize,
Standard: BorshSerialize,
bool: BorshSerialize,
Option<Vec<ExtensionInput>>: BorshSerialize,
impl BorshSerialize for CreateInstructionArgswhere
String: BorshSerialize,
Standard: BorshSerialize,
bool: BorshSerialize,
Option<Vec<ExtensionInput>>: BorshSerialize,
Sourceimpl Clone for CreateInstructionArgs
impl Clone for CreateInstructionArgs
Sourcefn clone(&self) -> CreateInstructionArgs
fn clone(&self) -> CreateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateInstructionArgs
impl Debug for CreateInstructionArgs
impl Eq for CreateInstructionArgs
Sourceimpl PartialEq for CreateInstructionArgs
impl PartialEq for CreateInstructionArgs
Sourcefn eq(&self, other: &CreateInstructionArgs) -> bool
fn eq(&self, other: &CreateInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateInstructionArgs