#[repr(u8)]pub enum Standard {
NonFungible = 0,
Managed = 1,
Soulbound = 2,
Proxied = 3,
}Expand description
Defines the standard of an asset.
Variants
NonFungible = 0
A unique (one-of-a-kind) asset.
Managed = 1
A unique managed asset.
Managed assets have an additional delegate that can control the asset. Holding a managed asset does not grant permanent ownership rights.
Soulbound = 2
A unique non-transferable asset.
Proxied = 3
A unique proxied asset (an asset that is controlled by another program).