pub struct ExtensionInput {
pub extension_type: ExtensionType,
pub length: u32,
pub data: Option<Vec<u8>>,
}Fields
extension_type: ExtensionTypelength: u32data: Option<Vec<u8>>Trait Implementations
Sourceimpl BorshDeserialize for ExtensionInput
impl BorshDeserialize for ExtensionInput
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ExtensionInput
impl BorshSerialize for ExtensionInput
Sourceimpl Clone for ExtensionInput
impl Clone for ExtensionInput
Sourcefn clone(&self) -> ExtensionInput
fn clone(&self) -> ExtensionInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionInput
impl Debug for ExtensionInput
impl Eq for ExtensionInput
Sourceimpl PartialEq for ExtensionInput
impl PartialEq for ExtensionInput
Sourcefn eq(&self, other: &ExtensionInput) -> bool
fn eq(&self, other: &ExtensionInput) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExtensionInput